<?php
/**
 * apuslisting functions and definitions
 *
 * Set up the theme and provides some helper functions, which are used in the
 * theme as custom template tags. Others are attached to action and filter
 * hooks in WordPress to change core functionality.
 *
 * When using a child theme you can override certain functions (those wrapped
 * in a function_exists() call) by defining them first in your child theme's
 * functions.php file. The child theme's functions.php file is included before
 * the parent theme's file, so the child theme functions would be used.
 *
 * @link https://codex.wordpress.org/Theme_Development
 * @link https://codex.wordpress.org/Child_Themes
 *
 * Functions that are not pluggable (not wrapped in function_exists()) are
 * instead attached to a filter or action hook.
 *
 * For more information on hooks, actions, and filters,
 * {@link https://codex.wordpress.org/Plugin_API}
 *
 * @package WordPress
 * @subpackage Apuslisting
 * @since Apuslisting 1.2.18
 */

define( 'APUSLISTING_THEME_VERSION', '1.2.18' );
define( 'APUSLISTING_DEMO_MODE', false );

if ( ! isset( $content_width ) ) {
	$content_width = 660;
}

if ( ! function_exists( 'apuslisting_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 *
 * @since Apuslisting 1.0
 */
function apuslisting_setup() {

	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on apuslisting, use a find and replace
	 * to change 'apuslisting' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'apuslisting', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * See: https://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	add_theme_support( 'post-thumbnails' );
	set_post_thumbnail_size( 825, 510, true );

	add_image_size( 'apuslisting-card-image', 358, 234, true );
	add_image_size( 'apuslisting-image-list', 250, 165, array( 'left', 'top' ) );
	add_image_size( 'apuslisting-image-gallery1', 480, 480, true );
	add_image_size( 'apuslisting-image-gallery2', 970, 585, true );
	
	// This theme uses wp_nav_menu() in two locations.
	register_nav_menus( array(
		'primary' => esc_html__( 'Primary Menu', 'apuslisting' ),
		'topmenu'  => esc_html__( 'Top Menu', 'apuslisting' ),
		'suggestions_search'  => esc_html__( 'Suggestions Search', 'apuslisting' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form', 'comment-form', 'comment-list', 'gallery', 'caption'
	) );

	add_theme_support( 'job-manager-templates' );
	add_theme_support( "woocommerce" );
	

	/*
	 * Enable support for Post Formats.
	 *
	 * See: https://codex.wordpress.org/Post_Formats
	 */
	add_theme_support( 'post-formats', array(
		'aside', 'image', 'video', 'quote', 'link', 'gallery', 'status', 'audio', 'chat'
	) );

	$color_scheme  = apuslisting_get_color_scheme();
	$default_color = trim( $color_scheme[0], '#' );

	// Setup the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'apuslisting_custom_background_args', array(
		'default-color'      => $default_color,
		'default-attachment' => 'fixed',
	) ) );

	add_editor_style( array( 'css/template.css' ) );

	apuslisting_get_load_plugins();
}
endif; // apuslisting_setup
add_action( 'after_setup_theme', 'apuslisting_setup' );

/**
 * Load Google Front
 */
function apuslisting_get_fonts_url() {
    $fonts_url = '';

    /* Translators: If there are characters in your language that are not
    * supported by Montserrat, translate this to 'off'. Do not translate
    * into your own language.
    */
    $roboto = _x( 'on', 'Roboto font: on or off', 'apuslisting' );
    $Josefin    = _x( 'on', 'Josefin font: on or off', 'apuslisting' );
 
    if ( 'off' !== $roboto || 'off' !== $Josefin ) {
        $font_families = array();
 
        if ( 'off' !== $roboto ) {
            $font_families[] = 'Roboto:300,400,500,700,900';
        }
        if ( 'off' !== $Josefin ) {
            $font_families[] = 'Josefin+Sans:400,600,700';
        }
 		$font_google_code = apuslisting_get_config('font_google_code');
 		if (!empty($font_google_code) ) {
 			$font_families[] = $font_google_code;
 		}
        $query_args = array(
            'family' => ( implode( '|', $font_families ) ),
            'subset' => urlencode( 'latin,latin-ext' ),
        );
 		
 		$protocol = is_ssl() ? 'https:' : 'http:';
        $fonts_url = add_query_arg( $query_args, $protocol .'//fonts.googleapis.com/css' );
    }
 
    return esc_url_raw( $fonts_url );
}

function apuslisting_fonts_url() {  
	$protocol = is_ssl() ? 'https:' : 'http:';
	wp_enqueue_style( 'apuslisting-theme-fonts', apuslisting_get_fonts_url(), array(), null );
}
add_action('wp_enqueue_scripts', 'apuslisting_fonts_url');

/**
 * JavaScript Detection.
 *
 * Adds a `js` class to the root `<html>` element when JavaScript is detected.
 *
 * @since Apuslisting 1.1
 */
function apuslisting_javascript_detection() {
	wp_add_inline_script( 'apuslisting-typekit', "(function(html){html.className = html.className.replace(/\bno-js\b/,'js')})(document.documentElement);" );
}
add_action( 'wp_enqueue_scripts', 'apuslisting_javascript_detection', 0 );

/**
 * Enqueue scripts and styles.
 *
 * @since Apuslisting 1.0
 */
function apuslisting_scripts() {
	// load animate version 3.5.0
	wp_enqueue_style( 'animate', get_template_directory_uri() . '/assets/css/animate.css', array(), '3.5.0' );
	
	wp_enqueue_style( 'apuslisting-style', get_template_directory_uri() . '/style.css', array(), '3.2' );
	//load font awesome
	wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/assets/css/font-awesome.css', array(), '4.5.0' );

	wp_enqueue_style( 'apus-icons', get_template_directory_uri() . '/assets/css/apus-icons.css', array(), '1.0.0' );

	// load bootstrap style
	if ( is_rtl() ) {
		wp_enqueue_style( 'bootstrap', get_template_directory_uri() . '/assets/css/bootstrap-rtl.css', array(), '3.2.0' );
	} else {
		wp_enqueue_style( 'bootstrap', get_template_directory_uri() . '/assets/css/bootstrap.css', array(), '3.2.0' );
	}

	wp_enqueue_style( 'apuslisting-template', get_template_directory_uri() . '/assets/css/template.css', array(), '3.2' );
	$footer_style = apuslisting_print_style_footer();
	if ( !empty($footer_style) ) {
		wp_add_inline_style( 'apuslisting-template', $footer_style );
	}
	
	$custom_style = apuslisting_custom_styles();
	if ( !empty($custom_style) ) {
		wp_add_inline_style( 'apuslisting-template', $custom_style );
	}

	wp_enqueue_script( 'skip-link-focus-fix', get_template_directory_uri() . '/assets/js/skip-link-focus-fix.js', array(), '20141010', true );
	wp_enqueue_script( 'jquery-unveil', get_template_directory_uri() . '/assets/js/jquery.unveil.js', array('jquery'), '20141010', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	wp_enqueue_script( 'bootstrap', get_template_directory_uri() . '/assets/js/bootstrap.min.js', array( 'jquery' ), '20150330', true );

	wp_enqueue_script( 'owl-carousel', get_template_directory_uri() . '/assets/js/owl.carousel.min.js', array( 'jquery' ), '2.0.0', true );

	wp_enqueue_script( 'apuslisting-countdown', get_template_directory_uri() . '/assets/js/countdown.js', array( 'jquery' ), '20150315', true );

	wp_enqueue_script( 'timepicker', get_template_directory_uri() . '/assets/js/timepicker/jquery.timepicker.min.js' );
	wp_enqueue_style( 'timepicker', get_template_directory_uri() . '/assets/js/timepicker/jquery.timepicker.css' );
	
	wp_enqueue_script( 'magnific', get_template_directory_uri() . '/assets/js/magnific/jquery.magnific-popup.min.js', array( 'jquery' ), '1.1.0', true );
	wp_enqueue_style( 'magnific', get_template_directory_uri() . '/assets/js/magnific/magnific-popup.css', array(), '1.1.0' );
	
	wp_enqueue_script( 'chosen', get_template_directory_uri() . '/assets/js/chosen.jquery.min.js', array( 'jquery' ), '1.1.0', true );
	wp_enqueue_style( 'chosen', get_template_directory_uri() . '/assets/css/chosen.css', array(), '1.1.0' );

	wp_enqueue_script( 'perfect-scrollbar', get_template_directory_uri() . '/assets/js/perfect-scrollbar.jquery.min.js', array( 'jquery' ), '20150315', true );
	wp_enqueue_style( 'perfect-scrollbar', get_template_directory_uri() . '/assets/css/perfect-scrollbar.css', array(), '2.3.2' );

	wp_register_script( 'apuslisting-script-functions', get_template_directory_uri() . '/assets/js/functions.js', array( 'jquery', 'jquery-ui-slider', 'wp-job-manager-ajax-filters' ), '20150330', true );
	wp_localize_script( 'apuslisting-script-functions', 'apuslisting_ajax', array(
		'ajaxurl' => admin_url( 'admin-ajax.php' ),
		'time_format' => str_replace( '\\', '\\\\', get_option( 'time_format' ) ),
		'closed_text' => esc_html__( 'Closed', 'apuslisting' )
	));
	wp_enqueue_script( 'apuslisting-script-functions' );

	if ( apuslisting_get_config('custom_js') != "" ) {
		wp_add_inline_script( 'apuslisting-script-functions', apuslisting_get_config('custom_js') );
	}
}
add_action( 'wp_enqueue_scripts', 'apuslisting_scripts', 100 );

/**
 * Display descriptions in main navigation.
 *
 * @since Apuslisting 1.0
 *
 * @param string  $item_output The menu item output.
 * @param WP_Post $item        Menu item object.
 * @param int     $depth       Depth of the menu.
 * @param array   $args        wp_nav_menu() arguments.
 * @return string Menu item with possible description.
 */
function apuslisting_nav_description( $item_output, $item, $depth, $args ) {
	if ( 'primary' == $args->theme_location && $item->description ) {
		$item_output = str_replace( $args->link_after . '</a>', '<div class="menu-item-description">' . $item->description . '</div>' . $args->link_after . '</a>', $item_output );
	}

	return $item_output;
}
add_filter( 'walker_nav_menu_start_el', 'apuslisting_nav_description', 10, 4 );

/**
 * Add a `screen-reader-text` class to the search form's submit button.
 *
 * @since Apuslisting 1.0
 *
 * @param string $html Search form HTML.
 * @return string Modified search form HTML.
 */
function apuslisting_search_form_modify( $html ) {
	return str_replace( 'class="search-submit"', 'class="search-submit screen-reader-text"', $html );
}
add_filter( 'get_search_form', 'apuslisting_search_form_modify' );

/**
 * Function get opt_name
 *
 */
function apuslisting_get_opt_name() {
	return 'apuslisting_theme_options';
}
add_filter( 'apus_framework_get_opt_name', 'apuslisting_get_opt_name' );
/**
 * Function register demo mode
 *
 */
function apuslisting_register_demo_mode() {
	if ( defined('APUSLISTING_DEMO_MODE') && APUSLISTING_DEMO_MODE ) {
		return true;
	}
	return false;
}
add_filter( 'apus_framework_register_demo_mode', 'apuslisting_register_demo_mode' );
/**
 * Function get demo preset
 *
 */
function apuslisting_get_demo_preset() {
	$preset = '';
    if ( defined('APUSLISTING_DEMO_MODE') && APUSLISTING_DEMO_MODE ) {
    	if ( is_admin() ) {
    		$preset = get_option( 'apus_framework_preset_default' );
    	} elseif ( isset($_COOKIE['apus_preset']) && $_COOKIE['apus_preset'] ) {
    		$presets = get_option( 'apus_framework_presets' );
            if ( is_array($presets) && isset($presets[$_COOKIE['apus_preset']]) ) {
                $preset = $_COOKIE['apus_preset'];
            }
    	} else {
            $preset = get_option( 'apus_framework_preset_default' );
        }
    }
    return $preset;
}
if ( defined('APUSLISTING_DEMO_MODE') && APUSLISTING_DEMO_MODE ) {
	function apuslisting_set_demo_preset() {
	    
        if ( isset($_GET['_preset']) && $_GET['_preset'] ) {
            $presets = get_option( 'apus_framework_presets' );
            if ( is_array($presets) && isset($presets[$_GET['_preset']]) ) {
                $preset = $_GET['_preset'];
                setcookie( 'apus_preset', trim($preset) , time() + 1*24*60*60,'/' );
            	$_COOKIE['apus_preset'] = trim($preset);
            }
        }
	    
	}
	add_action( 'init', 'apuslisting_set_demo_preset' );
}

function apuslisting_set_exporter_first_settings_option_keys($option_keys) {
	return array_merge($option_keys, array(
		'job_manager_enable_categories',
		'job_manager_enable_default_category_multiselect',
		'job_manager_submit_job_form_page_id',
		'job_manager_job_dashboard_page_id',
		'job_manager_jobs_page_id',
		'job_manager_favorite_page_id',
	));
}
add_filter( 'apus_exporter_first_settings_option_keys', 'apuslisting_set_exporter_first_settings_option_keys' );

function apuslisting_get_config($name, $default = '') {
	global $apus_options;
    if ( isset($apus_options[$name]) ) {
        return $apus_options[$name];
    }
    return $default;
}

function apuslisting_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar Default', 'apuslisting' ),
		'id'            => 'sidebar-default',
		'description'   => esc_html__( 'Add widgets here to appear in your Sidebar.', 'apuslisting' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Header Search Sidebar', 'apuslisting' ),
		'id'            => 'search-sidebar',
		'description'   => esc_html__( 'Add widgets here to appear in your Header.', 'apuslisting' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Blog sidebar', 'apuslisting' ),
		'id'            => 'blog-sidebar',
		'description'   => esc_html__( 'Add widgets here to appear in your sidebar.', 'apuslisting' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h2 class="widget-title"><span>',
		'after_title'   => '</span></h2>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Listing archive sidebar', 'apuslisting' ),
		'id'            => 'listing-archive-sidebar',
		'description'   => esc_html__( 'Add widgets here to appear in your sidebar.', 'apuslisting' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h2 class="widget-title"><span>',
		'after_title'   => '</span></h2>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Single listing sidebar before', 'apuslisting' ),
		'id'            => 'listing-sidebar-before',
		'description'   => esc_html__( 'Add widgets here to appear in your sidebar.', 'apuslisting' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h2 class="widget-title"><span>',
		'after_title'   => '</span></h2>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Single listing sidebar after', 'apuslisting' ),
		'id'            => 'listing-sidebar-after',
		'description'   => esc_html__( 'Add widgets here to appear in your sidebar.', 'apuslisting' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h2 class="widget-title"><span>',
		'after_title'   => '</span></h2>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'View Profile Sidebar', 'apuslisting' ),
		'id'            => 'view-profile-sidebar',
		'description'   => esc_html__( 'Add widgets here to appear in your sidebar.', 'apuslisting' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h2 class="widget-title"><span>',
		'after_title'   => '</span></h2>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'My Profile Sidebar', 'apuslisting' ),
		'id'            => 'my-profile-sidebar',
		'description'   => esc_html__( 'Add widgets here to appear in your sidebar.', 'apuslisting' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h2 class="widget-title"><span>',
		'after_title'   => '</span></h2>',
	) );
}
add_action( 'widgets_init', 'apuslisting_widgets_init' );

function apuslisting_get_load_plugins() {

	$plugins[] =(array(
		'name'                     => esc_html__( 'Apus Framework For Themes', 'apuslisting' ),
        'slug'                     => 'apus-framework',
        'required'                 => true ,
        'source'				   => get_template_directory() . '/inc/plugins/apus-framework.zip'
	));

	$plugins[] =(array(
		'name'                     => esc_html__( 'WPBakery Visual Composer', 'apuslisting' ),
	    'slug'                     => 'js_composer',
	    'required'                 => true,
	    'source'				   => get_template_directory() . '/inc/plugins/js_composer.zip'
	));
	
	$plugins[] =(array(
		'name'                     => esc_html__( 'Cmb2', 'apuslisting' ),
	    'slug'                     => 'cmb2',
	    'required'                 => true,
	));

	$plugins[] =(array(
		'name'                     => esc_html__( 'MailChimp for WordPress', 'apuslisting' ),
	    'slug'                     => 'mailchimp-for-wp',
	    'required'                 =>  true
	));

	$plugins[] =(array(
		'name'                     => esc_html__( 'Contact Form 7', 'apuslisting' ),
	    'slug'                     => 'contact-form-7',
	    'required'                 => true,
	));

	// listing manager plugins
	$plugins[] =(array(
		'name'                     => esc_html__( 'WP Job Manager', 'apuslisting' ),
	    'slug'                     => 'wp-job-manager',
	    'required'                 => true,
	));

	$plugins[] =(array(
		'name'                     => esc_html__( 'Apus Apuslisting', 'apuslisting' ),
        'slug'                     => 'apus-apuslisting',
        'required'                 => true ,
        'source'				   => get_template_directory() . '/inc/plugins/apus-apuslisting.zip'
	));

	// woocommerce plugins
	$plugins[] =(array(
		'name'                     => esc_html__( 'WooCommerce', 'apuslisting' ),
	    'slug'                     => 'woocommerce',
	    'required'                 => true,
	));

	tgmpa( $plugins );
}

require get_template_directory() . '/inc/plugins/class-tgm-plugin-activation.php';
require get_template_directory() . '/inc/functions-helper.php';
require get_template_directory() . '/inc/functions-frontend.php';

/**
 * Implement the Custom Header feature.
 *
 */
require get_template_directory() . '/inc/custom-header.php';
require get_template_directory() . '/inc/classes/megamenu.php';
require get_template_directory() . '/inc/classes/mobilemenu.php';
require get_template_directory() . '/inc/classes/userinfo.php';
/**
 * Custom template tags for this theme.
 *
 */
require get_template_directory() . '/inc/template-tags.php';

$active_plugins =  apply_filters( 'active_plugins', get_option( 'active_plugins' ) );
if ( defined( 'APUS_FRAMEWORK_REDUX_ACTIVED' ) ) {
	require get_template_directory() . '/inc/vendors/redux-framework/redux-config.php';
	define( 'APUSLISTING_REDUX_FRAMEWORK_ACTIVED', true );
}
if( in_array( 'cmb2/init.php', $active_plugins ) ) {
	require get_template_directory() . '/inc/vendors/cmb2/footer.php';
	require get_template_directory() . '/inc/vendors/cmb2/page.php';
	require get_template_directory() . '/inc/vendors/cmb2/product.php';
	define( 'APUSLISTING_CMB2_ACTIVED', true );
}
if( in_array( 'woocommerce/woocommerce.php', $active_plugins ) ) {
	require get_template_directory() . '/inc/vendors/woocommerce/functions.php';
	define( 'APUSLISTING_WOOCOMMERCE_ACTIVED', true );
}
if( defined('APUSLISTING_WOOCOMMERCE_ACTIVED') && in_array( 'yith-woocommerce-subscription/init.php', $active_plugins ) ) {
	require get_template_directory() . '/inc/vendors/yith-woocommerce-subscription/functions.php';
	require get_template_directory() . '/inc/vendors/yith-woocommerce-subscription/vc.php';
}
if( in_array( 'wp-job-manager/wp-job-manager.php', $active_plugins ) ) {
	require get_template_directory() . '/inc/vendors/wp-job-manager/functions.php';
	require get_template_directory() . '/inc/vendors/wp-job-manager/vc-functions.php';
	require get_template_directory() . '/inc/vendors/wp-job-manager/vc.php';
	require get_template_directory() . '/inc/vendors/wp-job-manager/functions-helper.php';
	require get_template_directory() . '/inc/vendors/wp-job-manager/functions-hook.php';
	require get_template_directory() . '/inc/vendors/wp-job-manager/functions-review.php';
	define( 'APUSLISTING_WP_JOB_MANAGER_ACTIVED', true );
}
if( in_array( 'js_composer/js_composer.php', $active_plugins ) ) {
	require get_template_directory() . '/inc/vendors/visualcomposer/functions.php';
	require get_template_directory() . '/inc/vendors/visualcomposer/vc-map-posts.php';
	require get_template_directory() . '/inc/vendors/visualcomposer/vc-map-theme.php';
	define( 'APUSLISTING_VISUALCOMPOSER_ACTIVED', true );
}
if( in_array( 'apus-framework/apus-framework.php', $active_plugins ) && class_exists('Apus_Widget') ) {
	require get_template_directory() . '/inc/widgets/custom_menu.php';
	require get_template_directory() . '/inc/widgets/recent_post.php';
	require get_template_directory() . '/inc/widgets/search.php';
	require get_template_directory() . '/inc/widgets/single_image.php';
	require get_template_directory() . '/inc/widgets/listing_search.php';
	require get_template_directory() . '/inc/widgets/user_short_profile.php';
	require get_template_directory() . '/inc/widgets/my_short_profile.php';
	require get_template_directory() . '/inc/widgets/listings.php';
	define( 'APUSLISTING_FRAMEWORK_ACTIVED', true );
}
if( in_array( 'nextend-facebook-connect/nextend-facebook-connect.php', $active_plugins ) ) {
	define( 'APUSLISTING_FACEBOOK_CONNECT_ACTIVED', true );
}
if( in_array( 'nextend-google-connect/nextend-google-connect.php', $active_plugins ) ) {
	define( 'APUSLISTING_GOOGLE_CONNECT_ACTIVED', true );
}
if( in_array( 'nextend-twitter-connect/nextend-twitter-connect.php', $active_plugins ) ) {
	define( 'APUSLISTING_TWITTER_CONNECT_ACTIVED', true );
}
if( in_array( 'wp-job-manager-wc-paid-listings/wp-job-manager-wc-paid-listings.php', $active_plugins ) ) {
	require get_template_directory() . '/inc/vendors/wc-paid-listings/functions.php';
	require get_template_directory() . '/inc/vendors/wc-paid-listings/vc.php';
	define( 'APUSLISTING_WC_PAID_LISTINGS_ACTIVED', true );
}
/**
 * Customizer additions.
 *
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Custom Styles
 *
 */
require get_template_directory() . '/inc/custom-styles.php';


function apuslisting_progress_import_steps($steps) {
	return array(
		'first_settings' => array( 'default' => esc_html__('Install First Settings', 'apuslisting'), 'installing' => esc_html__('Installing First Settings ...', 'apuslisting'), 'installed' => esc_html__('Installed First Settings', 'apuslisting') ),
		'content' => array( 'default' => esc_html__('Install Demo Content', 'apuslisting'), 'installing' => esc_html__('Installing Demo Content ...', 'apuslisting'), 'installed' => esc_html__('Installed Demo Content', 'apuslisting') ),
		'widgets' => array( 'default' => esc_html__('Install Widgets', 'apuslisting'), 'installing' => esc_html__('Installing Widgets ...', 'apuslisting'), 'installed' => esc_html__('Installed Widgets', 'apuslisting') ),
		'settings' => array( 'default' => esc_html__('Install Settings', 'apuslisting'), 'installing' => esc_html__('Installing Settings ...', 'apuslisting'), 'installed' => esc_html__('Installed Settings', 'apuslisting') ),
	);
}
add_filter('apus_frammework_progress_import_steps', 'apuslisting_progress_import_steps' );